==> reakit-0.14.5.tgz: package/es/Portal.js <==
import { d as _inheritsLoose, e as _assertThisInitialized, f as _defineProperty } from './chunk-fb907809.js';
import React__default from 'react';
import ReactDOM from 'react-dom';
import { prop } from 'styled-tools';
import styled from './styled.js';
import as from './as.js';
import Base from './Base.js';
import 'styled-components';
import '@emotion/is-prop-valid';
import 'prop-types';
import './chunk-254efadd.js';
import './chunk-a7ce379e.js';

var Component =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Component, _React$Component);

  function Component() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      wrapper: null
    });

    return _this;
  }

  var _proto = Component.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var wrapper = document.createElement("div");
    document.body.appendChild(wrapper);
    this.setState({
      wrapper: wrapper
    });
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var wrapper = this.state.wrapper;

    if (wrapper) {
      document.body.removeChild(wrapper);
    }
  };

  _proto.render = function render() {
    var wrapper = this.state.wrapper;

    if (wrapper) {
      return ReactDOM.createPortal(React__default.createElement(Base, this.props), wrapper);
    }

    return null;
  };

  return Component;
}(React__default.Component);

var Portal = styled(Component).withConfig({
  displayName: "Portal"
})(["", ";"], prop("theme.Portal"));
var Portal$1 = as("div")(Portal);

export default Portal$1;

==> reakit-0.14.6.tgz: package/es/Portal.js <==
import { d as _inheritsLoose, e as _assertThisInitialized, f as _defineProperty } from './chunk-fb907809.js';
import React__default, { createElement, Component } from 'react';
import { createPortal, findDOMNode } from 'react-dom';
import { prop } from 'styled-tools';
import hoistNonReactStatics from 'hoist-non-react-statics';
import styled from './styled.js';
import as from './as.js';
import Base from './Base.js';
import 'styled-components';
import '@emotion/is-prop-valid';
import 'prop-types';
import './chunk-254efadd.js';
import './chunk-a7ce379e.js';

var Component$1 =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Component$$1, _React$Component);

  function Component$$1() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      wrapper: null
    });

    return _this;
  }

  var _proto = Component$$1.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var wrapper = document.createElement("div");
    document.body.appendChild(wrapper);
    this.setState({
      wrapper: wrapper
    });
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var wrapper = this.state.wrapper;

    if (wrapper) {
      document.body.removeChild(wrapper);
    }
  };

  _proto.render = function render() {
    var wrapper = this.state.wrapper;

    if (wrapper) {
      return createPortal(createElement(Base, this.props), wrapper);
    }

    return null;
  };

  return Component$$1;
}(Component);

hoistNonReactStatics(Component$1, Base);
var Portal = styled(Component$1).withConfig({
  displayName: "Portal",
  componentId: "sc-1anvbga-0"
})(["", ";"], prop("theme.Portal"));
var Portal$1 = as("div")(Portal);

export default Portal$1;
